@@ -5,6 +5,7 @@ import uuid
 from decimal import Decimal
 
 from django.core.serializers.json import DjangoJSONEncoder
+from django.utils.functional import Promise
 from rest_framework.renderers import BaseRenderer
 from rest_framework.settings import api_settings
 
@@ -49,7 +50,7 @@ class ORJSONRenderer(BaseRenderer):
                 return str(obj)
             else:
                 return float(obj)
-        elif isinstance(obj, (str, uuid.UUID)):
+        elif isinstance(obj, (str, uuid.UUID, Promise)):
             return str(obj)
         elif hasattr(obj, "tolist"):
             return obj.tolist()
@@ -68,6 +69,9 @@ class ORJSONRenderer(BaseRenderer):
                 the following keys: view, request, response, args, kwargs
         :return: bytes() representation of the data encoded to UTF-8
         """
+        if data is None:
+            return b''
+
         renderer_context = renderer_context or {}
 
         # By default, this function will use its own version of `default()` in
